# -*- coding: utf-8 -*-
"""Project metadata."""

package = "lambdautils"
project = "lambdautils"
version = '0.2.7'
description = "Simple utilities for AWS Lambda functions"
authors = ["Innovative Travel Ltd"]
authors_string = ', '.join(authors)
emails = ['german@innovativetravel.eu']
license = 'MIT'
copyright = '2016 ' + authors_string
url = 'http://github.com/InnovativeTravel/humilis-lambdautils'
